﻿using Infragistics.Web.UI.GridControls;
using Infragistics.Web.UI.ListControls;
using System;
using System.Collections.Generic;
using System.Data;
using System.Linq;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;

public partial class _Default : System.Web.UI.Page
{
    protected void Page_Load(object sender, EventArgs e)
    {
        if (Session["GridData"] == null)
        {
            Session["GridData"] = GetDepartments();
            this.WebDataGrid1.DataSource = Session["GridData"];
        }
        else
        {
            this.WebDataGrid1.DataSource = Session["GridData"];
        }
        WebDropDown wdd = this.WebDataGrid1.EditorProviders["DropDownProvider1"].GetEditor() as WebDropDown;
        wdd.DataSource = GetDaysOfTheWeek();
        wdd.ValueField = "Key";
        wdd.TextField = "Value";
    }

    public Dictionary<int, string> GetDaysOfTheWeek()
    {
        Dictionary<int, string> daysOfTheWeek = new Dictionary<int, string>();
        daysOfTheWeek.Add(0, "Sunday");
        daysOfTheWeek.Add(1, "Monday");
        daysOfTheWeek.Add(2, "Tuesday");
        daysOfTheWeek.Add(3, "Wednesday");
        daysOfTheWeek.Add(4, "Thursday");
        daysOfTheWeek.Add(5, "Friday");
        daysOfTheWeek.Add(6, "Saturday");

        return daysOfTheWeek;
    }

    #region SampleData

    enum SampleTables
    {
        Departments,
        Employees,
        EmployeeOptions
    }

    private DataTable GetSampleTable(SampleTables table)
    {
        DataTable retVal;
        switch (table)
        {
            case SampleTables.Departments:
                retVal = this.GetDepartments();
                break;
            case SampleTables.Employees:
                retVal = this.GetEmployees();
                break;
            case SampleTables.EmployeeOptions:
                retVal = this.GetEmployeeOptions();
                break;
            default:
                retVal = this.GetEmployees();
                break;
        }
        return retVal;
    }

    private DataSet GetEmployDepartmentDataSet()
    {
        DataSet ds = new DataSet("EmployeeRecords");

        // Get the tables to use in the DataSet
        DataTable Employees = this.GetEmployees();
        DataTable Departments = this.GetDepartments();
        DataTable Options = this.GetEmployeeOptions();

        // Add the tables to the DataSet
        ds.Tables.Add(Departments);
        ds.Tables.Add(Employees);
        ds.Tables.Add(Options);

        // Create the relationship between the tables.
        ds.Relations.Add("DepartmentEmployee", Departments.Columns["DepartmentID"], Employees.Columns["Department"]);
        ds.Relations.Add("EmployeeOption", Employees.Columns["EmployeeID"], Options.Columns["Employee"]);
        return ds;
    }

    private DataTable GetDepartments()
    {
        DataTable dt = new DataTable("Departments");
        dt.Columns.Add("DepartmentID", typeof(int));
        dt.Columns.Add("DepartmentName", typeof(string));
        dt.Columns.Add("Provider", typeof(int));
        
        for (int i = 0; i < 8; i++)
        {
            dt.Rows.Add(new object[] { i, string.Format("Department {0}", i, i) });
        }

        dt.PrimaryKey = new DataColumn[] { dt.Columns["DepartmentID"] };

        return dt;
    }

    private DataTable GetEmployees()
    {
        return this.GetEmployees(24);
    }

    private DataTable GetEmployees(int count)
    {
        DataTable dtData = new DataTable("Employees");

        dtData.Columns.Add("EmployeeID", typeof(int));
        dtData.Columns.Add("Name", typeof(string));
        dtData.Columns.Add("OnSite", typeof(bool));
        dtData.Columns.Add("DateOfHire", typeof(DateTime));
        dtData.Columns.Add("Department", typeof(int));
        dtData.Columns.Add("Site", typeof(string));


        for (int i = 0; i < count; i++)
        {
            dtData.Rows.Add(new object[] { i, string.Format("Name {0}", i), (i % 2 == 0), DateTime.Today.Date.AddDays(-1 * i), i % 8, "http://www.google.com" });
        }

        dtData.PrimaryKey = new DataColumn[] { dtData.Columns["EmployeeID"] };

        return dtData;
    }

    private DataTable GetEmployeeOptions()
    {
        DataTable dtData = new DataTable("EmployeeOptions");

        dtData.Columns.Add("OptionID", typeof(int));
        dtData.Columns.Add("Employee", typeof(int));
        dtData.Columns.Add("Option", typeof(string));
        dtData.Columns.Add("Description", typeof(string));


        for (int i = 0; i < 96; i++)
        {
            dtData.Rows.Add(new object[] { i, i % 24, string.Format("Option {0}", i), String.Format("Option Description {0}", i) });
        }

        dtData.PrimaryKey = new DataColumn[] { dtData.Columns["OptionID"] };

        return dtData;
    }

    #endregion SampleData

    protected void WebDataGrid1_RowUpdating(object sender, Infragistics.Web.UI.GridControls.RowUpdatingEventArgs e)
    {
        GridRecord row = e.Row;
    }
    protected void WebDataGrid1_RowUpdated(object sender, Infragistics.Web.UI.GridControls.RowUpdatedEventArgs e)
    {
        IDPair rowID = e.RowID;
    }
}